@@ -21,14 +21,16 @@
 **************************************************************************/
 
 #include <QtGui/QApplication>
-#include "mainwindow.h"
+#include "seaview.h"
 
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
     a.setApplicationName("Ghosts Overboard");
-    a.setApplicationVersion("0.2.1");
-    MainWindow w;
+    a.setOrganizationName("Ghosts Overboard");
+    a.setApplicationVersion("0.3.0");
+    a.setWindowIcon(QIcon(":/pix/laiva_3aave.png"));
+    SeaView w;
 #if defined(Q_WS_S60)
     w.showMaximized();
 #else
